]> Sergey Matveev's repositories - nnn.git/commitdiff
fix the malloc size in get_archive_cmd
authorNRK <nrk@disroot.org>
Wed, 24 Nov 2021 15:53:11 +0000 (21:53 +0600)
committerNRK <nrk@disroot.org>
Wed, 24 Nov 2021 15:53:11 +0000 (21:53 +0600)
since the tr hack was removed in deead97, the format string is no longer
70 chars. also removes unnecessary malloc casting.

src/nnn.c

index 1c12e1cdb17f13c129a7ba5fd64dc71bbcfe1964..bd342362ab76b8061b81bf338c20cc07e3197ed3 100644 (file)
--- a/src/nnn.c
+++ b/src/nnn.c
@@ -2721,9 +2721,9 @@ static void get_archive_cmd(char *cmd, const char *archive)
 
 static void archive_selection(const char *cmd, const char *archive, const char *curpath)
 {
-       /* The 70 comes from the string below */
-       char *buf = (char *)malloc((70 + xstrlen(cmd) + xstrlen(archive)
-                                      + xstrlen(curpath) + xstrlen(selpath)) * sizeof(char));
+       /* The 38 comes from the format string below */
+       char *buf = malloc((38 + xstrlen(cmd) + xstrlen(archive)
+                              + xstrlen(curpath) + xstrlen(selpath)) * sizeof(char));
        if (!buf) {
                DPRINTF_S(strerror(errno));
                printwarn(NULL);